@@ -7,10 +7,14 @@ import sys
 sys.path.insert(0, '/usr/share/dstat/')
 import dstat
 
+### Set default theme
+dstat.theme = dstat.set_theme()
+
 clear = dstat.ansi['reset']
+dstat.tick = dstat.ticks()
 
 c = dstat.dstat_cpu()
-print c.title1() + '\n' + c.title2()
+print c.title() + '\n' + c.subtitle()
 c.extract()
 print c.show(), clear
 print 'Percentage:', c.val['total']
@@ -18,21 +22,21 @@ print 'Raw:', c.cn2['total']
 print
 
 m = dstat.dstat_mem()
-print m.title1() + '\n' + m.title2()
+print m.title() + '\n' + m.subtitle()
 m.extract()
 print m.show(), clear
 print 'Raw:', m.val
 print
 
 l = dstat.dstat_load()
-print l.title1() + '\n' + l.title2()
+print l.title() + '\n' + l.subtitle()
 l.extract()
 print l.show(), clear
 print 'Raw:', l.val
 print
 
 d = dstat.dstat_disk()
-print d.title1() + '\n' + d.title2()
+print d.title() + '\n' + d.subtitle()
 d.extract()
 print d.show(), clear
 print 'Raw:', d.val['total']
