@@ -12,25 +12,25 @@ class dstat_plugin(dstat):
         self.width = 3
         self.scale = 1000
 
-    def check(self): 
+    def check(self):
         if os.access('/usr/bin/mysql', os.X_OK):
             try:
                 self.stdin, self.stdout, self.stderr = dpopen('/usr/bin/mysql -n %s' % mysql_options)
             except IOError:
-                raise Exception, 'Cannot interface with MySQL binary'
+                raise Exception('Cannot interface with MySQL binary')
             return True
-        raise Exception, 'Needs MySQL binary'
+        raise Exception('Needs MySQL binary')
 
     def extract(self):
         try:
             self.stdin.write('show engine innodb status\G\n')
-            line = greppipe(self.stdout, 'OS file reads ')
+            line = matchpipe(self.stdout, '.*OS file reads,.*')
 
             if line:
                 l = line.split()
-                self.set2['read'] = l[0].rstrip(',')
-                self.set2['write'] = l[4].rstrip(',')
-                self.set2['sync'] = l[8]
+                self.set2['read'] = int(l[0])
+                self.set2['write'] = int(l[4])
+                self.set2['sync'] = int(l[8])
 
             for name in self.vars:
                 self.val[name] = (self.set2[name] - self.set1[name]) * 1.0 / elapsed
@@ -38,12 +38,12 @@ class dstat_plugin(dstat):
             if step == op.delay:
                 self.set1.update(self.set2)
 
-        except IOError, e:
-            if op.debug > 1: print '%s: lost pipe to mysql, %s' % (self.filename, e)
+        except IOError as e:
+            if op.debug > 1: print('%s: lost pipe to mysql, %s' % (self.filename, e))
             for name in self.vars: self.val[name] = -1
 
-        except Exception, e:
-            if op.debug > 1: print '%s: exception' % (self.filename, e)
+        except Exception as e:
+            if op.debug > 1: print('%s: exception' % (self.filename, e))
             for name in self.vars: self.val[name] = -1
 
 # vim:ts=4:sw=4:et
