@@ -3,10 +3,11 @@
 class dstat_plugin(dstat):
     def __init__(self):
         self.nick = ('read', 'write')
+        self.cols = 2 
 
     def check(self):
         if not os.path.exists('/proc/fs/lustre/llite'):
-            raise Exception, 'Lustre filesystem not found'
+            raise Exception('Lustre filesystem not found')
         info(1, 'Module %s is still experimental.' % self.filename)
 
     def name(self):
@@ -17,15 +18,17 @@ class dstat_plugin(dstat):
 
     def extract(self):
         for name in self.vars:
-            for l in open(os.path.join('/proc/fs/lustre/llite', name, 'stats')).splitlines():
+            for line in dopen(os.path.join('/proc/fs/lustre/llite', name, 'stats')).readlines():
+                l = line.split()
                 if len(l) < 6: continue
                 if l[0] == 'read_bytes':
-                    read = long(l[6])
+                    read = int(l[6])
                 elif l[0] == 'write_bytes':
-                    write = long(l[6])
+                    write = int(l[6])
             self.set2[name] = (read, write)
-            self.val[name] = ( (self.set2[name][0] - self.set1[name][0]) * 1.0 / elapsed,
-                               (self.set2[name][1] - self.set1[name][1]) * 1.0 / elapsed )
+
+            self.val[name] = list(map(lambda x, y: (y - x) * 1.0 / elapsed, self.set1[name], self.set2[name]))
+
         if step == op.delay:
             self.set1.update(self.set2)
 
