@@ -6,6 +6,15 @@ mysql_user = os.getenv('DSTAT_MYSQL_USER') or os.getenv('USER')
 global mysql_pwd
 mysql_pwd = os.getenv('DSTAT_MYSQL_PWD')
 
+global mysql_host
+mysql_host = os.getenv('DSTAT_MYSQL_HOST')
+
+global mysql_port
+mysql_port = os.getenv('DSTAT_MYSQL_PORT')
+
+global mysql_socket
+mysql_socket = os.getenv('DSTAT_MYSQL_SOCKET')
+
 class dstat_plugin(dstat):
     """
     Plugin for MySQL 5 I/O.
@@ -20,9 +29,21 @@ class dstat_plugin(dstat):
         global MySQLdb
         import MySQLdb
         try:
-            self.db = MySQLdb.connect(user=mysql_user, passwd=mysql_pwd)
+            args = {}
+            if mysql_user:
+                args['user'] = mysql_user
+            if mysql_pwd:
+                args['passwd'] = mysql_pwd
+            if mysql_host:
+                args['host'] = mysql_host
+            if mysql_port:
+                args['port'] = mysql_port
+            if mysql_socket:
+                args['unix_socket'] = mysql_socket
+
+            self.db = MySQLdb.connect(**args)
         except:
-            raise Exception, 'Cannot interface with MySQL server'
+            raise Exception('Cannot interface with MySQL server')
 
     def extract(self):
         try:
@@ -32,7 +53,9 @@ class dstat_plugin(dstat):
             for line in lines:
                 if len(line[1]) < 2: continue
                 if line[0] in self.vars:
-                    self.set2[line[0]] = float(line[1])
+                    if line[0] + 'raw' in self.set2:
+                        self.set2[line[0]] = float(line[1]) - self.set2[line[0] + 'raw']
+                    self.set2[line[0] + 'raw'] = float(line[1])
 
             for name in self.vars:
                 self.val[name] = self.set2[name] * 1.0 / elapsed
@@ -40,7 +63,7 @@ class dstat_plugin(dstat):
             if step == op.delay:
                 self.set1.update(self.set2)
 
-        except Exception, e:
+        except Exception as e:
             for name in self.vars:
                 self.val[name] = -1
 
