@@ -11,15 +11,17 @@ class dstat_plugin(dstat):
         self.open('/proc/net/rpc/nfsd')
 
     def check(self):
-        info(1, 'Module %s is still experimental.') % self.filename
+        info(1, 'Module %s is still experimental.' % self.filename)
 
     def extract(self):
         for l in self.splitlines():
             if not l or l[0] != 'proc3': continue
             for i, name in enumerate(self.vars):
-                self.set2[name] = long(l[i+2])
+                self.set2[name] = int(l[i+2])
+
         for name in self.vars:
             self.val[name] = (self.set2[name] - self.set1[name]) * 1.0 / elapsed
+
         if step == op.delay:
             self.set1.update(self.set2)
 
